@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.040-10-g6731cc8
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.041-7-g969c3d9
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.041';
+our $VERSION = '0.042';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -155,7 +155,7 @@ sub stale_modules
         next if $already_checked{$module};
 
         # these core modules should be indexed, but aren't
-        if (any { $module eq $_ } qw(Config DB Errno integer NEXT Pod::Functions))
+        if (any { $module eq $_ } qw(Config DB Errno NEXT Pod::Functions))
         {
             $self->log_debug([ 'skipping core module: %s', $module ]);
             $already_checked{$module}++;
@@ -448,7 +448,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
